@@ -2,7 +2,7 @@
 PublicKey
 */
 
-use crate::cose::CoseKey;
+use crate::encrypt::cose::CoseKey;
 use crate::util;
 use serde_cbor::Value;
 use std::fmt;
