@@ -2,8 +2,8 @@
 Verify Attestation Assertion API
 */
 
-use crate::get_assertion_params;
-use crate::make_credential_params;
+use crate::fidokey::get_assertion::get_assertion_params;
+use crate::fidokey::make_credential::make_credential_params;
 use crate::util;
 use ring::digest;
 use ring::rand::SecureRandom;
